@@ -115,7 +115,7 @@ typedef unsigned int guintptr;
 
 #define GLIB_MAJOR_VERSION 2
 #define GLIB_MINOR_VERSION 86
-#define GLIB_MICRO_VERSION 3
+#define GLIB_MICRO_VERSION 4
 
 #define G_OS_UNIX
 
@@ -213,7 +213,7 @@ typedef int GPid;
 #define G_SEARCHPATH_SEPARATOR ':'
 #define G_SEARCHPATH_SEPARATOR_S ":"
 
-#undef G_HAVE_FREE_SIZED
+#define G_HAVE_FREE_SIZED
 
 G_END_DECLS
 
